==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2305_171.zip: ronportal/ronportal/personalistika/pracovniomezeniosobybrowser.php <==
<?php
/**
 * pavel.rudol, 03.05.2023 10:01
 */

namespace RonPortal\Personalistika;

use Ron\Controls\BrowserField;
use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\FilterFormFilter;
use RonPortal\Controls\FilterFormFilterItem;
use RonPortal\Controls\OsobniCisloBrowserField;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Prava;
use RonPortal\RozdeleniUtils;

class PracovniOmezeniOsobyBrowser extends RonPortalBrowser
{
    protected $prava;

    public function __construct($database)
    {
        parent::__construct($database, 'pracovniomezeniosoby');

        Prava::nastavObdobiProPrava(time(), time());
        $this->filterFormRights = 'prohl_osobni';

        $this->prava = Prava::vratPrava($this->filterFormRights);

        $this->code = 'browseromezeniosoby';
        $this->tableId = 'browseromezeniosoby';

        $this->title = TextManager::_('Pracovni_omezeni_osoby');

        $this->sqlFromPart =
            'PracovniOmezeniOsoby JOIN Osoba ON (Osoba.RC = PracovniOmezeniOsoby.RC) ' .
            'JOIN CiselnikPracovnichOmezeni ON (CiselnikPracovnichOmezeni.Kod = PracovniOmezeniOsoby.KodOmezeni)';

        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('Osoba.RC')->setCode('col-rc');

        $this->addField()
            ->setSqlFieldName('Osoba.Prijmeni')->setHeaderText('Prijmeni')
            ->setCode('col-prijmeni')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('Osoba.Jmeno')->setHeaderText('Jmeno')
            ->setCode('col-jmeno')->setOrdering(true);
        $this->addField(new OsobniCisloBrowserField($this->database, 'col-rc'))->setCode('col-osobni-cislo');
        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('CiselnikPracovnichOmezeni.Kod')
            ->setCode('col-omezeni');
        $this->addField()
            ->setSqlFieldName('CiselnikPracovnichOmezeni.Popis')->setHeaderText('Pracovni_omezeni')
            ->setCode('col-omezeni-popis')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('PracovniOmezeniOsoby.DatumOd')->setHeaderText('Platnost_od')
            ->setFormat('date')->setAlign('right')->setOrdering(true)
            ->setCode('col-platnost-od');
        $this->addField()
            ->setSqlFieldName('PracovniOmezeniOsoby.DatumDo')->setHeaderText('Platnost_do')
            ->setFormat('date')->setAlign('right')->setOrdering(true)
            ->setCode('col-platnost-do');

        $this->defaultSort = 'col-platnost-od';
    }

    function setFilterForm()
    {
        parent::setFilterForm();

        $this->filterForm->setUseGet(true, $this->action);
        $this->filterForm->nastavObdobi(false, '', false);
        $this->filterForm->povolitVsechyOsoby = true;

        $params = $this->database->createParameters();

        $omezeniFilter = new FilterFormFilter('omezeni', FilterFormFilter::TYPE_OPTIONS);
        $omezeniFilter
            ->setCaption(TextManager::_('Pracovni_omezeni'))
            ->setRowId('filterrow_omezeni')
            ->setSessionName('filterrow_omezeni')
            ->setItems(['' => new FilterFormFilterItem('', TextManager::_('_vse_'))])
            ->setOptionsSql('SELECT Kod, Popis FROM CiselnikPracovnichOmezeni')
            ->setAddClass('ronselect')
            ->setHtmlAttributes(['data-ronselect-class' => 'adsfilterforminput_full ronselect'])
            ->setSqlFilter('CiselnikPracovnichOmezeni.Kod = ');
        $this ->filterForm ->addFilter($omezeniFilter);

        $platneFilter = new FilterFormFilter('stav');
        $platneFilter
            ->setRowId('filterrow_stav')
            ->setSessionName('filterform_stav')
            ->addItem(new FilterFormFilterItem(0, TextManager::_('Vse')))
            ->addItem((new FilterFormFilterItem(1, TextManager::_('Pracovni_omezeni_jen_platne')))->setSqlFilter(
                new SqlStatement('PracovniOmezeniOsoby.DatumOd <= ' . $params->addDateParameter(time()) . ' AND (PracovniOmezeniOsoby.DatumDo >= ' . $params->addDateParameter(time()) . ' OR PracovniOmezeniOsoby.DatumDo IS NULL)',
                    $params)));
        $this ->filterForm ->addFilter($platneFilter);
    }

    public function loadConfigurationItem($key, $value, $valueText)
    {
        if ($key === 'filtrovatPodleTypuPrava') {
            $this->prava = Prava::vratPrava($valueText);
        } else {
            parent::loadConfigurationItem($key, $value, $valueText);
        }
    }


    public function getSQLFilter()
    {
        $params = $this->database->createParameters();

        $datumOd = DateUtils::today();
        $datumDo = DateUtils::today();

        $sql =
            ' EXISTS(SELECT ID FROM PracovniPomer ' .
            '   WHERE PracovniPomer.RC = Osoba.RC ' .
            '     AND PracovniPomer.DatumNastupu <= ' . $params->addDateParameter($datumDo) .
            '     AND (PracovniPomer.DatumUkonceni >= ' . $params->addDateParameter($datumOd) . ' OR PracovniPomer.DatumUkonceni IS NULL)' .
            '     AND ' . $this->prava->sqlFiltr('PracovniPomer', $datumOd, $datumDo, $params);

        if ($this->filterForm->kodRozdeleni) {
            $sql .= ' AND ' . RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer', $this->filterForm->kodTypuRozdeleni, $this->filterForm->kodRozdeleni, $datumOd, $datumDo, $this->filterForm->vcetnePodrizenychRozdeleni, $params);
        }
        if ($this->filterForm->kodRozdeleni2) {
            $sql .= ' AND ' . RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer', $this->filterForm->kodTypuRozdeleni2, $this->filterForm->kodRozdeleni2, $datumOd, $datumDo, $this->filterForm->vcetnePodrizenychRozdeleni2, $params);
        }

        $sql .=
            ')';

        if ($this->filterForm->vybranaOsobaRC) {
            $sql .= ' AND Osoba.RC = ' . $params->addParameter($this->filterForm->vybranaOsobaRC);
        }

        $filter = $this->filterForm->buildSqlFilter($params);
        if ($filter) {
            $sql .= ' AND ' . $filter;
        }

        return new SqlStatement($sql, $params);
    }


}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/personalistika/pracovniomezeniosobybrowser.php <==
<?php
/**
 * pavel.rudol, 03.05.2023 10:01
 */

namespace RonPortal\Personalistika;

use Ron\Controls\BrowserField;
use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\FilterFormFilter;
use RonPortal\Controls\FilterFormFilterItem;
use RonPortal\Controls\OsobniCisloBrowserField;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RozdeleniUtils;

class PracovniOmezeniOsobyBrowser extends RonPortalBrowser
{
    /** @var PravaNaOsoby|PravaNaOsoby[] */
    protected $prava;

    public function __construct($database)
    {
        parent::__construct($database, 'pracovniomezeniosoby');

        Prava::nastavObdobiProPrava(time(), time());
        $this->filterFormRights = Prava::vratPrava('lekarske_prohl');

        $this->prava = $this->filterFormRights;

        $this->code = 'browseromezeniosoby';
        $this->tableId = 'browseromezeniosoby';

        $this->title = TextManager::_('Pracovni_omezeni_osoby');

        $this->sqlFromPart =
            'PracovniOmezeniOsoby JOIN Osoba ON (Osoba.RC = PracovniOmezeniOsoby.RC) ' .
            'JOIN CiselnikPracovnichOmezeni ON (CiselnikPracovnichOmezeni.Kod = PracovniOmezeniOsoby.KodOmezeni)';

        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('Osoba.RC')->setCode('col-rc');

        $this->addField()
            ->setSqlFieldName('Osoba.Prijmeni')->setHeaderText('Prijmeni')
            ->setCode('col-prijmeni')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('Osoba.Jmeno')->setHeaderText('Jmeno')
            ->setCode('col-jmeno')->setOrdering(true);
        $this->addField(new OsobniCisloBrowserField($this->database, 'col-rc'))->setCode('col-osobni-cislo');
        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('CiselnikPracovnichOmezeni.Kod')
            ->setCode('col-omezeni');
        $this->addField()
            ->setSqlFieldName('CiselnikPracovnichOmezeni.Popis')->setHeaderText('Pracovni_omezeni')
            ->setCode('col-omezeni-popis')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('PracovniOmezeniOsoby.DatumOd')->setHeaderText('Platnost_od')
            ->setFormat('date')->setAlign('right')->setOrdering(true)
            ->setCode('col-platnost-od');
        $this->addField()
            ->setSqlFieldName('PracovniOmezeniOsoby.DatumDo')->setHeaderText('Platnost_do')
            ->setFormat('date')->setAlign('right')->setOrdering(true)
            ->setCode('col-platnost-do');

        $this->defaultSort = 'col-platnost-od';
    }

    function setFilterForm()
    {
        $this ->filterForm = new RonPortalFilterForm($this ->database, $this ->action, true);

        $prava = Prava::vratPrava('lekarske_prohl');
        $this ->filterForm ->addFilterRozdeleni1(null, $prava);
        $this ->filterForm ->addFilterRozdeleni2(null, $prava);

        $this ->filterForm ->nastavOsoby(true, $prava);
        $this->filterForm->povolitVsechyOsoby = true;

        $omezeniFilter = new FilterFormFilter('omezeni', FilterFormFilter::TYPE_OPTIONS);
        $omezeniFilter
            ->setCaption(TextManager::_('Pracovni_omezeni'))
            ->setRowId('filterrow_omezeni')
            ->setSessionName('filterrow_omezeni')
            ->setItems(['' => new FilterFormFilterItem('', TextManager::_('_vse_'))])
            ->setOptionsSql('SELECT Kod, Popis FROM CiselnikPracovnichOmezeni')
            ->setAddClass('ronselect')
            ->setHtmlAttributes(['data-ronselect-class' => 'adsfilterforminput_full ronselect'])
            ->setSqlFilter('CiselnikPracovnichOmezeni.Kod = ');
        $this ->filterForm ->addFilter($omezeniFilter);

        $params = $this->database->createParameters();
        $platneFilter = new FilterFormFilter('stav');
        $platneFilter
            ->setRowId('filterrow_stav')
            ->setSessionName('filterform_stav')
            ->addItem(new FilterFormFilterItem(0, TextManager::_('Vse')))
            ->addItem(
                (new FilterFormFilterItem(1, TextManager::_('Pracovni_omezeni_jen_platne')))
                    ->setSqlFilter(
                        new SqlStatement(
                            'PracovniOmezeniOsoby.DatumOd <= ' . $params->addDateParameter(time()) .
                            ' AND (PracovniOmezeniOsoby.DatumDo >= ' . $params->addDateParameter(time()) .
                            ' OR PracovniOmezeniOsoby.DatumDo IS NULL)',
                        $params)));
        $this ->filterForm ->addFilter($platneFilter);
    }

    public function loadConfigurationItem($key, $value, $valueText)
    {
        if ($key === 'filtrovatPodleTypuPrava') {
            $this->prava = Prava::vratPrava($valueText);
        } else {
            parent::loadConfigurationItem($key, $value, $valueText);
        }
    }


    public function getSQLFilter()
    {
        $params = $this->database->createParameters();

        $datumOd = DateUtils::today();
        $datumDo = DateUtils::today();

        $sql =
            ' EXISTS(SELECT ID FROM PracovniPomer ' .
            '   WHERE PracovniPomer.RC = Osoba.RC ' .
            '     AND PracovniPomer.DatumNastupu <= ' . $params->addDateParameter($datumDo) .
            '     AND (PracovniPomer.DatumUkonceni >= ' . $params->addDateParameter($datumOd) . ' OR PracovniPomer.DatumUkonceni IS NULL)' .
            '     AND (';

        if (is_array($this->prava)) {
            $sqlPrava = '';
            foreach ($this->prava as $pravo) {
                if ($sqlPrava !== '') {
                    $sqlPrava .= ' OR ';
                }
                $sqlPrava .= $pravo->sqlFiltr('PracovniPomer', $datumOd, $datumDo, $params);
            }
            $sql .= $sqlPrava;
        } else {
            $sql .= $this->prava->sqlFiltr('PracovniPomer', $datumOd, $datumDo, $params);
        }
        $sql .= ')';

//        if ($this->filterForm->kodRozdeleni) {
//            $sql .= ' AND ' . RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer', $this->filterForm->kodTypuRozdeleni, $this->filterForm->kodRozdeleni, $datumOd, $datumDo, $this->filterForm->vcetnePodrizenychRozdeleni, $params);
//        }
//        if ($this->filterForm->kodRozdeleni2) {
//            $sql .= ' AND ' . RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer', $this->filterForm->kodTypuRozdeleni2, $this->filterForm->kodRozdeleni2, $datumOd, $datumDo, $this->filterForm->vcetnePodrizenychRozdeleni2, $params);
//        }

        if ($this->filterForm->vybranaOsobaRC) {
            $sql .= ' AND Osoba.RC = ' . $params->addParameter($this->filterForm->vybranaOsobaRC);
        } else {
            foreach ($this ->filterForm ->getRozdeleniFilters() as $rozdeleniFilter) {
                $sqlRozdeleni = $rozdeleniFilter ->sestavSQLFiltr($this ->database,
                    'PracovniPomer',
                    $params
                );

                if ($sqlRozdeleni) {
                    $sql .= ' AND ' . $sqlRozdeleni;
                }
            }
        }

        $sql .=
            ')';

        $filter = $this->filterForm->buildSqlFilter($params);
        if ($filter) {
            $sql .= ' AND ' . $filter;
        }

        return new SqlStatement($sql, $params);
    }


}
